local addon = LibStub('AceAddon-3.0'):GetAddon('KuiNameplates')
local kui = LibStub('Kui-1.0')

_G['KuiNameplatesFilesLoaded-150'] = true

------------------------------------------------------------------ Background --
function addon:CreateBackground(frame, f)
	-- frame glow
	f.bg:SetParent(f.parent)
	f.bg:SetTexture('Interface\\AddOns\\Kui_Nameplates\\media\\FrameGlow')
	f.bg:SetTexCoord(0, .469, 0, .625)
	f.bg:SetVertexColor(0, 0, 0, .9)

	-- solid background
	f.bg.fill = f.parent:CreateTexture(nil, 'BACKGROUND')
	f.bg.fill:SetTexture(kui.m.t.solid)
	f.bg.fill:SetVertexColor(0, 0, 0, .8)
	f.bg.fill:SetDrawLayer('ARTWORK', 1) -- 1 sub-layer above .bg

	f.bg.fill:SetSize(addon.sizes.width, addon.sizes.height)
	f.bg.fill:SetPoint('BOTTOMLEFT', f.x, f.y)

	f.bg:ClearAllPoints()
	f.bg:SetPoint('BOTTOMLEFT',
		f.x - addon.sizes.bgOffset,
		f.y - addon.sizes.bgOffset)
	f.bg:SetPoint('TOPRIGHT', f.parent, 'BOTTOMLEFT',
		f.x + addon.sizes.width + addon.sizes.bgOffset,
		f.y + addon.sizes.height + addon.sizes.bgOffset)
end

------------------------------------------------------------------ Health bar --
function addon:CreateHealthBar(frame, f)
	f.health = CreateFrame('StatusBar', nil, f.parent)
	f.health:SetStatusBarTexture(kui.m.t.bar)

	f.health:ClearAllPoints()
	f.health:SetSize(addon.sizes.width-2, addon.sizes.height-2)
	f.health:SetPoint('BOTTOMLEFT', f.x+1, f.y+1)

	if addon.SetValueSmooth then
		-- smooth bar
		f.health.OrigSetValue = f.health.SetValue
		f.health.SetValue = addon.SetValueSmooth
	end
end

------------------------------------------------------------------- Highlight --
function addon:CreateHighlight(frame, f)
	if not addon.db.profile.general.highlight then return end

	f.highlight = f.overlay:CreateTexture(nil, 'ARTWORK')
	f.highlight:SetTexture(kui.m.t.bar)
	f.highlight:SetAllPoints(f.health)

	f.highlight:SetVertexColor(1, 1, 1)
	f.highlight:SetBlendMode('ADD')
	f.highlight:SetAlpha(.4)
	f.highlight:Hide()
end

----------------------------------------------------------------- Health text --
function addon:CreateHealthText(frame, f)
	f.health.p = f:CreateFontString(f.overlay, {
		font = addon.font, size = 'large', outline = "OUTLINE" })
	f.health.p:SetJustifyH('RIGHT')
	f.health.p:SetPoint('BOTTOMRIGHT', f.health, 'TOPRIGHT',
		-2, addon.uiscale and -(3/addon.uiscale) or -3)
end
function addon:UpdateHealthText(frame)
	if f.trivial then
		f.health.p:Hide()
	else
		f.health.p:Show()
	end
end

------------------------------------------------------------- Alt health text --
function addon:CreateAltHealthText(frame, f)
	f.health.mo = f:CreateFontString(f.overlay, {
		font = addon.font, size = 'small', outline = "OUTLINE" })
	f.health.mo:SetJustifyH('RIGHT')
	f.health.mo:SetPoint('BOTTOMRIGHT', f.health,
		-2, addon.uiscale and -(3/addon.uiscale) or -3)
	f.health.mo:SetAlpha(.6)
end
function addon:UpdateAltHealthText(frame, f)
	if f.trivial then
		f.health.mo:Hide()
	else
		f.health.mo:Show()
	end
end
function addon:DisableAltHealthText(frame, f)
	f.health.mo:Hide()
end

------------------------------------------------------------------ Level text --
function addon:CreateLevel(frame, f)
	if not f.level then return end
	
	f.level = f:CreateFontString(f.level, { reset = true,
		font = addon.font, size = 'name', outline = 'OUTLINE' })
	f.level:SetParent(f.overlay)
	
	f.level:ClearAllPoints()
	f.level:SetPoint('BOTTOMLEFT', f.health, 'TOPLEFT',
		2, addon.uiscale and -(2/addon.uiscale) or -2)
	f.level.enabled = true
end
function addon:UpdateLevel(frame, f)
	if f.trivial then
		f.level:Hide()
	else
		f.level:Show()
	end
	
	self:UpdateName(frame, f)
end
function addon:HideLevel(frame, f)
	f.level:Hide()
	f.level.enabled = nil
end

------------------------------------------------------------------- Name text --
function addon:CreateName(frame, f)	
	f.name = f:CreateFontString(f.overlay, {
		font = addon.font, size = 'name', outline = 'OUTLINE' })
	f.name:SetHeight(13)
	
	self:UpdateName(frame, f)
end
function addon:UpdateName(frame, f)
	if not f.name then return end
	
	f.name:ClearAllPoints()
	
	if f.trivial then
		addon.SetFontSize(f.name, addon.fontSizes.small)
	
		f.name:SetJustifyH('CENTER')
		f.name:SetPoint('BOTTOMLEFT', f.health, 'TOPLEFT', -10, 0)
		f.name:SetPoint('BOTTOMRIGHT', f.health, 'TOPRIGHT', 10, 0)
	else
		addon.SetFontSize(f.name, addon.fontSizes.name)
	
		f.name:SetJustifyH('LEFT')
		f.name:SetPoint('RIGHT', f.health.p, 'LEFT')
	
		if f.level and f.level.enabled then
			f.name:SetPoint('LEFT', f.level, 'RIGHT', -2, 0)
		else
			f.name:SetPoint('BOTTOMLEFT', f.health, 'TOPLEFT',
				2, addon.uiscale and -(2/addon.uiscale) or -2)
		end
	end
end
